@@ -1,8 +1,12 @@
 mod functions;
 mod number;
+mod number_128;
 
 #[doc(inline)]
 pub use functions::*;
 
 #[doc(inline)]
 pub use number::*;
+
+#[doc(inline)]
+pub use number_128::*;
